import * as api from './api.js'

Page({
  data: {
    account: '',
    password: '',
    disabled: false
  },
  onLoad: function (options) {},
  // 处理提交
  handleSubmit(e) {
    const { account, password } = this.data
    const params = {
      account,
      password,
      type: 2,
      service: 'https://h5.ezijing.com'
    }
    if (!account) {
      wx.showToast({ title: '请输入手机号', icon: 'none' })
      return
    }
    if (!password) {
      wx.showToast({ title: '请输入验证码', icon: 'none' })
      return
    }
    this.handleRequest(params)
  },
  // 请求接口
  handleRequest(params) {
    api.login(params).then(response => {
      const { code, msg, data } = response
      code === 0 ? this.handleSuccess(data) : this.handleError(response)
    })
  },
  // 登录成功
  handleSuccess(data) {
    wx.setStorage({ key: 'token', data: data.TGC })
    wx.switchTab({ url: '/pages/learnSystem/home/home' })
  },
  handleError(response) {
    if (response.msg === '账号不存在') {
      wx.showModal({ title: '账号不存在', content: '是否要成为学员', showCancel: true }).then(res => {
        res.confirm &&
          wx.navigateTo({
            url: `/pages/web/index?url=${encodeURIComponent('https://webapp-pub.ezijing.com/pages/prp/prp.html?channel_num=93530')}`
          })
      })
    } else {
      wx.showToast({ title: response.msg, icon: 'none' })
    }
  },
  // 发送验证码
  handleSendCode() {
    if (this.data.disabled) {
      return
    }
    if (!/^1[3-9][0-9]{9}$/.test(this.data.account)) {
      wx.showToast({ title: '请输入手机号', icon: 'none' })
      return
    }
    this.handleSendCodeRequest()
  },
  handleSendCodeRequest() {
    this.setData({ disabled: true })
    // 开始倒计时
    const countdown = this.selectComponent('.countdown')
    countdown.start()
    api
      .sendCode({ account: this.data.account })
      .then(response => {
        const { code, msg } = response
        if (code === 0) {
          wx.showToast({ title: '验证码发送成功', icon: 'none' })
        } else {
          countdown.reset()
          this.setData({ disabled: false })
          wx.showToast({ title: msg, icon: 'none' })
        }
      })
      .catch(response => {
        countdown.reset()
        this.setData({ disabled: false })
      })
  }
})
